-- widget title=Table migration status, row=1, col=0, size_x=2, size_y=8

## 1 - Table migration status

The table on the right assist with verifying if and how the tables are migrated. It can be filtered on the table name
and migration status. Next to table metadata, the table shows:
- The table name before migrating
- The migration status
- If migrated, the table name after migrating

The table migration status is updated after running
[table migration workflow](https://github.com/databrickslabs/ucx/blob/main/README.md#table-migration-workflow).
